@@ -58,14 +58,12 @@
  *      serialization format to describe the <link linkend="GstEncodeBin--profile"><type>GstEncodeBin.profile</type></link>
  *     property of the encodebin.
  *    </para>
- *
  *    <para>
  *        The simplest serialized profile looks like:
  *    </para>
  *    <informalexample>
  *      <programlisting>muxer_source_caps:videoencoder_source_caps:audioencoder_source_caps</programlisting>
  *    </informalexample>
- *
  *     <para>
  *         For example to encode a stream into a WebM container, with an OGG audio stream and a VP8 video stream,
  *         the serialized <link linkend="GstEncodingProfile"><type>GstEncodingProfile</type></link> will look like:
@@ -73,14 +71,12 @@
  *     <informalexample>
  *       <programlisting>video/webm:video/x-vp8:audio/x-vorbis</programlisting>
  *     </informalexample>
- *
  *    <para>
  *        You can also set the preset name of the encoding profile using the caps+preset_name syntax as in:
  *    </para>
  *    <informalexample>
  *      <programlisting>video/webm:video/x-vp8+youtube-preset:audio/x-vorbis</programlisting>
  *    </informalexample>
- *
  *    <para>
  *        Moreover, you can set the <link linkend="gst-encoding-profile-set-presence">presence</link> property of an
  *        encoding profile using the <code>|presence</code> syntax as in:
@@ -88,7 +84,6 @@
  *    <informalexample>
  *       <programlisting>video/webm:video/x-vp8|1:audio/x-vorbis</programlisting>
  *    </informalexample>
- *
  *    <para>
  *      This field allows you to specify how many times maximum a <link linkend="GstEncodingProfile"><type>GstEncodingProfile</type></link> can be used inside an encodebin.
  *    </para>
@@ -117,14 +112,12 @@
  *    <informalexample>
  *      <programlisting>video/quicktime,variant=iso:video/x-h264:audio/mpeg,mpegversion=1,layer=3</programlisting>
  *    </informalexample>
- *
  *    <para>
  *      Vorbis and theora in OGG:
  *    </para>
  *    <informalexample>
  *      <programlisting>application/ogg:video/x-theora:audio/x-vorbis</programlisting>
  *    </informalexample>
- *
  *     <para>
  *      AC3 and H264 in MPEG-TS:
  *    </para>
@@ -1496,6 +1489,65 @@ gst_encoding_profile_deserialize_valfunc (GValue * value, const gchar * s)
   return FALSE;
 }
 
+static gboolean
+add_stream_to_profile (GstEncodingContainerProfile * profile,
+    GstDiscovererStreamInfo * sinfo)
+{
+  GstEncodingProfile *sprofile = NULL;
+  GstStructure *s;
+  GstCaps *caps;
+
+  caps = gst_discoverer_stream_info_get_caps (sinfo);
+
+  s = gst_caps_get_structure (caps, 0);
+  if (gst_structure_has_field (s, "codec_data")
+      || gst_structure_has_field (s, "streamheader")) {
+    caps = gst_caps_make_writable (caps);
+    s = gst_caps_get_structure (caps, 0);
+    gst_structure_remove_field (s, "codec_data");
+    gst_structure_remove_field (s, "streamheader");
+  }
+
+  GST_LOG ("Stream: %" GST_PTR_FORMAT "\n", caps);
+  if (GST_IS_DISCOVERER_AUDIO_INFO (sinfo)) {
+    sprofile =
+        (GstEncodingProfile *) gst_encoding_audio_profile_new (caps, NULL,
+        NULL, 0);
+  } else if (GST_IS_DISCOVERER_VIDEO_INFO (sinfo)) {
+    sprofile =
+        (GstEncodingProfile *) gst_encoding_video_profile_new (caps, NULL,
+        NULL, 0);
+  } else if (GST_IS_DISCOVERER_CONTAINER_INFO (sinfo)) {
+    GList *streams, *stream;
+    guint n_streams = 0;
+
+    streams =
+        gst_discoverer_container_info_get_streams (GST_DISCOVERER_CONTAINER_INFO
+        (sinfo));
+    for (stream = streams; stream; stream = stream->next) {
+      if (add_stream_to_profile (profile,
+              (GstDiscovererStreamInfo *) stream->data))
+        n_streams++;
+    }
+    gst_discoverer_stream_info_list_free (streams);
+    gst_caps_unref (caps);
+
+    return n_streams != 0;
+  } else {
+    GST_WARNING ("Ignoring stream of type '%s'",
+        g_type_name (G_OBJECT_TYPE (sinfo)));
+    /* subtitles or other ? ignore for now */
+  }
+  if (sprofile)
+    gst_encoding_container_profile_add_profile (profile, sprofile);
+  else
+    GST_ERROR ("Failed to create stream profile from caps %" GST_PTR_FORMAT,
+        caps);
+  gst_caps_unref (caps);
+
+  return sprofile != NULL;
+}
+
 /**
  * gst_encoding_profile_from_discoverer:
  * @info: (transfer none): The #GstDiscovererInfo to read from
@@ -1513,6 +1565,7 @@ gst_encoding_profile_from_discoverer (GstDiscovererInfo * info)
   GstDiscovererStreamInfo *sinfo;
   GList *streams, *stream;
   GstCaps *caps = NULL;
+  guint n_streams = 0;
 
   if (!info || gst_discoverer_info_get_result (info) != GST_DISCOVERER_OK)
     return NULL;
@@ -1537,29 +1590,17 @@ gst_encoding_profile_from_discoverer (GstDiscovererInfo * info)
       gst_discoverer_container_info_get_streams (GST_DISCOVERER_CONTAINER_INFO
       (sinfo));
   for (stream = streams; stream; stream = stream->next) {
-    GstEncodingProfile *sprofile = NULL;
-    sinfo = (GstDiscovererStreamInfo *) stream->data;
-    caps = gst_discoverer_stream_info_get_caps (sinfo);
-    GST_LOG ("Stream: %" GST_PTR_FORMAT "\n", caps);
-    if (GST_IS_DISCOVERER_AUDIO_INFO (sinfo)) {
-      sprofile =
-          (GstEncodingProfile *) gst_encoding_audio_profile_new (caps, NULL,
-          NULL, 0);
-    } else if (GST_IS_DISCOVERER_VIDEO_INFO (sinfo)) {
-      sprofile =
-          (GstEncodingProfile *) gst_encoding_video_profile_new (caps, NULL,
-          NULL, 0);
-    } else {
-      /* subtitles or other ? ignore for now */
-    }
-    if (sprofile)
-      gst_encoding_container_profile_add_profile (profile, sprofile);
-    else
-      GST_ERROR ("Failed to create stream profile from caps %" GST_PTR_FORMAT,
-          caps);
-    gst_caps_unref (caps);
+    if (add_stream_to_profile (profile,
+            (GstDiscovererStreamInfo *) stream->data))
+      n_streams++;
   }
   gst_discoverer_stream_info_list_free (streams);
 
+  if (n_streams == 0) {
+    GST_ERROR ("Failed to add any streams");
+    g_object_unref (profile);
+    return NULL;
+  }
+
   return (GstEncodingProfile *) profile;
 }
